@@ -26,7 +26,7 @@
 #       You may only use this script to uninstall the version
 #       shown below. Simply run this script to remove Shorewall Firewall
 
-VERSION=4.4.6
+VERSION=4.4.10.1
 
 usage() # $1 = exit status
 {
@@ -67,7 +67,7 @@ if qt ip6tables -L shorewall -n && [ ! -f /sbin/shorewall6 ]; then
 fi
 
 if [ -L /usr/share/shorewall6-lite/init ]; then
-    FIREWALL=$(ls -l /usr/share/shorewall6-lite/init | sed 's/^.*> //')
+    FIREWALL=$(readlink -m -q /usr/share/shorewall6-lite/init)
 else
     FIREWALL=/etc/init.d/shorewall6-lite
 fi
@@ -94,6 +94,7 @@ rm -rf /var/lib/shorewall6-lite
 rm -rf /var/lib/shorewall6-lite-*.bkout
 rm -rf /usr/share/shorewall6-lite
 rm -rf /usr/share/shorewall6-lite-*.bkout
+rm -f  /etc/logrotate.d/shorewall6-lite
 
 echo "Shorewall6 Lite Uninstalled"
 
